@@ -1,3 +1,5 @@
+from os import getenv
+
 from airflow import DAG
 from airflow.operators.python_operator import PythonOperator
 from datetime import datetime, timedelta
@@ -7,7 +9,9 @@ from finance_scraping.main import extract, transform, load
 default_args = {
     'owner': 'airflow',
     'depends_on_past': False,
-    'start_date': datetime(2019, 9, 4),
+    'start_date': datetime.strptime(
+        getenv('FINANCE_SCRAPING_DAG_START_DATE'),
+        '%Y-%m-%dT%H:%M'),
     'email_on_failure': False,
     'email_on_retry': False,
     'retries': 1,
@@ -17,7 +21,7 @@ default_args = {
 dag = DAG(
     'finance_scraping_etl',
     default_args=default_args,
-    schedule_interval='0 0 * * 1-5'
+    schedule_interval='0 22 * * 1-5'
 )
 
 extract_task = PythonOperator(
